@@ -2,7 +2,7 @@ import os
 import time
 
 from requests import Request, Session
-from Tea.exceptions import TeaException
+from Tea.exceptions import TeaException, RequiredArgumentException
 from urllib.parse import urlencode
 from Tea.response import TeaResponse
 from Tea.model import TeaModel
@@ -14,7 +14,11 @@ DEFAULT_READ_TIMEOUT = 10000
 class TeaCore:
     @staticmethod
     def compose_url(request):
-        host = request.headers.get('host', '').rstrip('/')
+        host = request.headers.get('host')
+        if not host:
+            raise RequiredArgumentException('endpoint')
+        else:
+            host = host.rstrip('/')
         protocol = '%s://' % request.protocol.lower()
         pathname = request.pathname
 
@@ -63,20 +67,29 @@ class TeaCore:
                           data=request.body, headers=request.headers)
             prepped = s.prepare_request(req)
 
+            proxies = {}
             http_proxy = runtime_option.get('httpProxy')
             https_proxy = runtime_option.get('httpsProxy')
+            no_proxy = runtime_option.get('noProxy')
 
             if not http_proxy:
                 http_proxy = os.environ.get('HTTP_PROXY') or os.environ.get('http_proxy')
             if not https_proxy:
                 https_proxy = os.environ.get('HTTPS_PROXY') or os.environ.get('https_proxy')
 
-            proxies = {
-                "http": http_proxy,
-                "https": https_proxy,
-            }
-            resp = s.send(prepped, proxies=proxies,
-                          timeout=timeout, verify=verify, cert=None)
+            if http_proxy:
+                proxies['http'] = http_proxy
+            if https_proxy:
+                proxies['https'] = https_proxy
+            if no_proxy:
+                proxies['no_proxy'] = no_proxy
+
+            resp = s.send(
+                prepped,
+                proxies=proxies,
+                timeout=timeout,
+                verify=verify,
+            )
             return TeaResponse(resp)
 
     @staticmethod
