@@ -1,11 +1,21 @@
 import re
+from .exceptions import RequiredArgumentException
 
 
 class TeaModel:
+    def validate(self):
+        pass
+
+    def to_map(self):
+        pass
+
+    def from_map(self):
+        pass
+
     @staticmethod
     def validate_required(prop, prop_name):
         if prop is None:
-            raise Exception(prop_name + ' is required.')
+            raise RequiredArgumentException(prop_name + ' is required.')
 
     @staticmethod
     def validate_max_length(prop, prop_name, max_length):
@@ -19,7 +29,7 @@ class TeaModel:
 
     @staticmethod
     def validate_pattern(prop, prop_name, pattern):
-        match_obj = re.search(pattern, prop, re.M | re.I)
+        match_obj = re.search(pattern, str(prop), re.M | re.I)
         if not match_obj:
             raise Exception(prop_name + ' is not match : ' + pattern)
 
